@@ -1,7 +1,7 @@
 bwplot.by.var <-
 function(xmat, log = FALSE, wend = 0.05, notch = FALSE, xlab = "Measured Variables", 
 	ylab = "Reported Values", main = "", label = NULL, plot.order = NULL, 
-	xpos = NA, las = 1, cex = 1, adj = 0.5, colr = 8, pch = 3, ...)
+	xpos = NA, las = 1, cex.axis = 1, adj = 0.5, colr = 8, pch = 3, ...)
 {
      # Function to plot multiple variables from a dataframe or matrix, as distinct
      # from subsets for a single variable, as box-and-whisker plots; the variables
@@ -21,7 +21,7 @@ function(xmat, log = FALSE, wend = 0.05, notch = FALSE, xlab = "Measured Variabl
          label <- sort(unique(x))
      bwplot(split(y, x), log = log, wend = wend, notch = notch, xlab = xlab,
          ylab = ylab, main = main, label = label, plot.order = plot.order,
-         xpos = xpos, las = las, cex = cex, adj = adj, colr = colr,
+         xpos = xpos, las = las, cex.axis = cex.axis, adj = adj, colr = colr,
          pch = pch, ...)
      invisible()
 }
