@@ -1,10 +1,11 @@
 gx.ecdf <-
-function(xx, xlab = deparse(substitute(xx)), ylab = "Empirical Cumulative Distribution Function", 
-     log = FALSE, xlim = NULL, main = " ", pch = 3, ifqs = FALSE)
+function(xx, xlab = deparse(substitute(xx)),
+         ylab = "Empirical Cumulative Distribution Function", log = FALSE,
+         xlim = NULL, main = "", pch = 3, ifqs = FALSE, cex = 0.8, ...)
 {
-     # Function to plot the plain vanilla empirical cumulative distribution function
-     # (ECDF) for a variable.  Optionally the data may be presented with log scaling
-     # and the quartiles plotted.
+     # Function to plot the plain vanilla empirical cumulative distribution
+     # function (ECDF) for a variable.  Optionally the data may be presented
+     # with log scaling and the quartiles plotted.
      #
      # NOTE: Prior to using this function the data frame/matrix containing the
      # variable, 'xx', data must be run through ltdl.fix.df to convert any <dl
@@ -19,19 +20,20 @@ function(xx, xlab = deparse(substitute(xx)), ylab = "Empirical Cumulative Distri
      if(log) {
          logx <- "x"
          if((!is.null(xlim)) && (xlim[1] <= 0))
-          xlim[1] <- min(x)
+             xlim[1] <- min(x)
      }
      else logx <- ""
      if(is.null(xlim)) {
-         plot(x, y, log = logx, xlab = xlab, ylab = ylab, main = main, pch = pch, las = 1)
+         plot(x, y, log = logx, xlab = xlab, ylab = ylab, main = main,
+              pch = pch, las = 1, ...)
          limits <- par("usr")
          nxx <- nx
      }
      else {
          xt <- x[(x >= xlim[1]) & (x <= xlim[2])]
          yt <- y[(x >= xlim[1]) & (x <= xlim[2])]
-         plot(xt, yt, log = logx, xlim = xlim, xlab = xlab, ylab = ylab, main = main,
-             pch = pch, las = 1)
+         plot(xt, yt, log = logx, xlim = xlim, xlab = xlab, ylab = ylab,
+              main = main, pch = pch, las = 1, ...)
          limits <- par("usr")
          nxx <- length(xt)
      }
@@ -40,13 +42,14 @@ function(xx, xlab = deparse(substitute(xx)), ylab = "Empirical Cumulative Distri
          abline(v = quantile(x, probs = c(0.25, 0.5, 0.75)), lty = 3)
      }
      xpos <- limits[2] - (limits[2] - limits[1]) * 0.05
-     ypos <- limits[3] + (limits[4] - limits[3]) * 0.15
+     ypos <- limits[3] + (limits[4] - limits[3]) * 0.11
      if(log)
          xpos <- 10^xpos
-     text(xpos, ypos, labels = paste("N =", nx), adj = 1)
+     text(xpos, ypos, labels = paste("N =", nx), adj = 1, cex = cex)
      if(nxx != nx) {
-         ypos <- limits[3] + (limits[4] - limits[3]) * 0.06
-         text(xpos, ypos, labels = paste(nx - nxx, "points omitted"), adj = 1)
+         ypos <- limits[3] + (limits[4] - limits[3]) * 0.05
+         text(xpos, ypos, labels = paste(nx - nxx, "points omitted"), adj = 1,
+             cex = cex * 0.8)
      }
      invisible()
 }
