@@ -1,6 +1,6 @@
 thplot2 <-
 function(x, name = deparse(substitute(x)), ifzero = 0.01, xlow = NA, xhih = NA,
-     yhih = NA, rsd = 5, ptile = 95, main = "", ifalt = FALSE)
+     yhih = NA, rsd = 5, ptile = 95, main = "", ifalt = FALSE, ...)
 {
      # Function to display a Thompson-Howarth plot for duplicate measurements.
      # Duplicate measurements are input as a single vector: X[1], ... X[n]
@@ -37,7 +37,7 @@ function(x, name = deparse(substitute(x)), ifzero = 0.01, xlow = NA, xhih = NA,
      }
      #
      thplot1(x1, x2, name = name, ifzero = ifzero, xlow = xlow, xhih = xhih,
-         yhih = yhih, rsd = rsd, ptile = ptile, main = main)
+         yhih = yhih, rsd = rsd, ptile = ptile, main = main, ...)
      invisible()
 }
 
